@@ -4,7 +4,7 @@ import os
 from dotenv import load_dotenv
 from jinja2 import Environment, PackageLoader, select_autoescape
 
-load_dotenv()
+load_dotenv(override=True)
 
 logging.basicConfig(format="%(levelname)s: %(message)s", level=logging.INFO)
 log = logging.getLogger(__name__)
@@ -14,7 +14,6 @@ JINJA_ENV = Environment(loader=PackageLoader("fhir_cli"), autoescape=select_auto
 # CDMs
 
 FHIR_ID = "fhir"
-CDM_LIST = [FHIR_ID]
 FHIR_API_URL = os.environ.get("FHIR_API_URL", "http://localhost:8080/fhir")
 FHIR_COLUMN_NAME = FHIR_ID
 
@@ -22,7 +21,6 @@ FHIR_COLUMN_NAME = FHIR_ID
 
 DBT_SCHEMA = os.environ.get("DBT_SCHEMA", "dbt")
 FHIR_DBT_SCHEMA = f"{DBT_SCHEMA}_{FHIR_ID}"
-DBT_INCREMENTAL_MODEL_TEMPLATE = "dbt_incremental_model.sql.j2"
 DBT_MODELS_DIR = "models"
 DBT_META_TABLE = "_meta"
 INIT_DB_TEMPLATE = "init_db.sql.j2"
