@@ -163,12 +163,8 @@ class Cli:
                 number_print(repr(fhir))
                 try:
                     fhir.validate()
-                    log.info("\U0001F525 resource is valid")
-                    # The message will be printed in GREEN, hence the weird sequence
-                    # at the beginning and at the end
                     log.info(f"{Fore.GREEN}✅ FHIR resource is valid")
                 except FhirValidationError as e:
-                    # Same as above
                     log.error(f"{Fore.RED}❌ FHIR resource is not valid\n{e}")
                 input("Press [Return] for the next result or [Ctrl+c] to quit")
         except ProgrammingError as e:
